Module: HalClient::EntryPointCovenienceMethods
- Included in:
- HalClient
- Defined in:
- lib/hal_client.rb
Instance Method Summary collapse
-
#delete(url, options = {}) ⇒ Object
Delete the resource identified at
url. -
#get(url, options = {}) ⇒ Object
Returns a
Representationof the resource identified byurl. -
#patch(url, data, options = {}) ⇒ Object
Patch a
RepresentationorStringto the resource identified aturl. -
#post(url, data, options = {}) ⇒ Object
Post a
RepresentationorStringto the resource identified aturl.
Instance Method Details
#delete(url, options = {}) ⇒ Object
Delete the resource identified at url.
url - The URL of the resource of interest. options - set of options to pass to ‘RestClient#get`
332 333 334 |
# File 'lib/hal_client.rb', line 332 def delete(url, ={}) default_client.delete(url, ) end |
#get(url, options = {}) ⇒ Object
Returns a Representation of the resource identified by url.
url - The URL of the resource of interest. options - set of options to pass to ‘RestClient#get`
306 307 308 |
# File 'lib/hal_client.rb', line 306 def get(url, ={}) default_client.get(url, ) end |
#patch(url, data, options = {}) ⇒ Object
Patch a Representation or String to the resource identified at url.
url - The URL of the resource of interest. data - a String or an object that responds to #to_hal options - set of options to pass to ‘RestClient#get`
324 325 326 |
# File 'lib/hal_client.rb', line 324 def patch(url, data, ={}) default_client.patch(url, data, ) end |
#post(url, data, options = {}) ⇒ Object
Post a Representation or String to the resource identified at url.
url - The URL of the resource of interest. data - a String or an object that responds to #to_hal options - set of options to pass to ‘RestClient#get`
315 316 317 |
# File 'lib/hal_client.rb', line 315 def post(url, data, ={}) default_client.post(url, data, ) end |