Module: HalClient::EntryPointCovenienceMethods
- Included in:
- HalClient
- Defined in:
- lib/hal_client.rb
Instance Method Summary collapse
-
#get(url, options = {}) ⇒ Object
Returns a
Representationof the resource identified byurl. -
#post(url, data, options = {}) ⇒ Object
Post a
RepresentationorStringto the resource identified aturl.
Instance Method Details
#get(url, options = {}) ⇒ Object
Returns a Representation of the resource identified by url.
url - The URL of the resource of interest. options - set of options to pass to ‘RestClient#get`
70 71 72 |
# File 'lib/hal_client.rb', line 70 def get(url, ={}) default_client.get(url, ) end |
#post(url, data, options = {}) ⇒ Object
Post a Representation or String to the resource identified at url.
url - The URL of the resource of interest. data - a String or an object that responds to #to_hal options - set of options to pass to ‘RestClient#get`
79 80 81 |
# File 'lib/hal_client.rb', line 79 def post(url, data, ={}) default_client.post(url, data, ) end |